@@ -190,6 +190,26 @@ class SidebandCore():
         self.config["connect_i2p_b32"] = "mrwqlsioq4hoo2lmeeud7dkfscnm7yxak7dmiyvsrnpfag3z5tsq.b32.i2p"
         self.config["connect_i2p_ifac_netname"] = ""
         self.config["connect_i2p_ifac_passphrase"] = ""
+        self.config["connect_rnode"] = False
+        self.config["connect_rnode_ifac_netname"] = ""
+        self.config["connect_rnode_ifac_passphrase"] = ""
+        # Hardware
+        self.config["hw_rnode_frequency"] = None
+        self.config["hw_rnode_modulation"] = "LoRa"
+        self.config["hw_rnode_bandwidth"] = 62500
+        self.config["hw_rnode_spreading_factor"] = 8
+        self.config["hw_rnode_coding_rate"] = 6
+        self.config["hw_rnode_tx_power"] = 0
+        self.config["hw_rnode_beaconinterval"] = None
+        self.config["hw_rnode_beacondata"] = None
+        self.config["hw_modem_preamble"] = 150
+        self.config["hw_modem_tail"] = 20
+        self.config["hw_modem_persistence"] = 220
+        self.config["hw_modem_slottime"] = 20
+        self.config["hw_serial_baudrate"] = 57600
+        self.config["hw_serial_databits"] = 8
+        self.config["hw_serial_stopbits"] = 1
+        self.config["hw_serial_parity"] = "none"
 
         if not os.path.isfile(self.db_path):
             self.__db_init()
@@ -223,6 +243,47 @@ class SidebandCore():
             self.config["lxmf_sync_interval"] = 43200
         if not "notifications_on" in self.config:
             self.config["notifications_on"] = True
+        if not "connect_rnode" in self.config:
+            self.config["connect_rnode"] = False
+        if not "connect_rnode_ifac_netname" in self.config:
+            self.config["connect_rnode_ifac_netname"] = ""
+        if not "connect_rnode_ifac_passphrase" in self.config:
+            self.config["connect_rnode_ifac_passphrase"] = ""
+        
+        if not "hw_rnode_frequency" in self.config:
+            self.config["hw_rnode_frequency"] = None
+        if not "hw_rnode_modulation" in self.config:
+            self.config["hw_rnode_modulation"] = "LoRa"
+        if not "hw_rnode_bandwidth" in self.config:
+            self.config["hw_rnode_bandwidth"] = 62500
+        if not "hw_rnode_spreading_factor" in self.config:
+            self.config["hw_rnode_spreading_factor"] = 8
+        if not "hw_rnode_coding_rate" in self.config:
+            self.config["hw_rnode_coding_rate"] = 6
+        if not "hw_rnode_tx_power" in self.config:
+            self.config["hw_rnode_tx_power"] = 0
+        if not "hw_rnode_beaconinterval" in self.config:
+            self.config["hw_rnode_beaconinterval"] = None
+        if not "hw_rnode_beacondata" in self.config:
+            self.config["hw_rnode_beacondata"] = None
+
+        if not "hw_modem_preamble" in self.config:
+            self.config["hw_modem_preamble"] = 150
+        if not "hw_modem_tail" in self.config:
+            self.config["hw_modem_tail"] = 20
+        if not "hw_modem_persistence" in self.config:
+            self.config["hw_modem_persistence"] = 220
+        if not "hw_modem_slottime" in self.config:
+            self.config["hw_modem_slottime"] = 20
+        
+        if not "hw_serial_baudrate" in self.config:
+            self.config["hw_serial_baudrate"] = 57600
+        if not "hw_serial_databits" in self.config:
+            self.config["hw_serial_databits"] = 8
+        if not "hw_serial_stopbits" in self.config:
+            self.config["hw_serial_stopbits"] = 1
+        if not "hw_serial_parity" in self.config:
+            self.config["hw_serial_parity"] = "none"
 
         # Make sure we have a database
         if not os.path.isfile(self.db_path):
@@ -937,11 +998,25 @@ class SidebandCore():
 
     def _service_jobs(self):
         if self.is_service:
+            last_usb_discovery = time.time()
             while True:
                 time.sleep(SidebandCore.SERVICE_JOB_INTERVAL)
+                now = time.time()
                 if self.getstate("wants.announce"):
                     self.lxmf_announce()
 
+                if (now - last_usb_discovery > 5):
+                    if self.interface_rnode != None and not self.interface_rnode.online:
+                        self.owner_app.discover_usb_devices()
+                        last_usb_discovery = time.time()
+
+                        if hasattr(self.owner_app, "usb_devices") and self.owner_app.usb_devices != None:
+                            if len(self.owner_app.usb_devices) > 0:
+                                target_device = self.owner_app.usb_devices[0]
+                                if self.interface_rnode.port != target_device["port"]:
+                                    RNS.log("Updating RNode device to "+str(target_device))
+                                    self.interface_rnode.port = target_device["port"]
+
     def _periodic_jobs(self):
         if self.is_service or self.is_standalone:
             while True:
@@ -992,6 +1067,7 @@ class SidebandCore():
         else:
             selected_level = 2
 
+        self.setstate("init.loadingstate", "Substantiating Reticulum")
         self.reticulum = RNS.Reticulum(configdir=self.rns_configdir, loglevel=selected_level)
 
         if RNS.vendor.platformutils.get_platform() == "android":
@@ -1001,8 +1077,10 @@ class SidebandCore():
                 self.interface_local = None
                 self.interface_tcp   = None
                 self.interface_i2p   = None
+                self.interface_rnode = None
 
                 if self.config["connect_local"]:
+                    self.setstate("init.loadingstate", "Discovering Topography")
                     try:
                         RNS.log("Adding Auto Interface...")
                         if self.config["connect_local_groupid"] == "":
@@ -1034,6 +1112,7 @@ class SidebandCore():
                         self.interface_local = None
 
                 if self.config["connect_tcp"]:
+                    self.setstate("init.loadingstate", "Connecting TCP Tunnel")
                     try:
                         RNS.log("Adding TCP Interface...")
 
@@ -1070,6 +1149,7 @@ class SidebandCore():
                         self.interface_tcp = None
 
                 if self.config["connect_i2p"]:
+                    self.setstate("init.loadingstate", "Opening I2P Endpoints")
                     try:
                         if self.config["connect_i2p_b32"].endswith(".b32.i2p"):
 
@@ -1103,7 +1183,51 @@ class SidebandCore():
                         RNS.log("Error while adding I2P Interface. The contained exception was: "+str(e))
                         self.interface_i2p = None
 
+                if self.config["connect_rnode"]:
+                    self.setstate("init.loadingstate", "Starting RNode")
+                    try:
+                        RNS.log("Adding RNode Interface...")
+
+                        target_device = None
+                        if len(self.owner_app.usb_devices) > 0:
+                            # TODO: Add more intelligent selection here
+                            target_device = self.owner_app.usb_devices[0]
+
+                        if target_device:
+                            if self.config["connect_rnode_ifac_netname"] == "":
+                                ifac_netname = None
+                            else:
+                                ifac_netname = self.config["connect_rnode_ifac_netname"]
+
+                            if self.config["connect_rnode_ifac_passphrase"] == "":
+                                ifac_netkey = None
+                            else:
+                                ifac_netkey = self.config["connect_rnode_ifac_passphrase"]
+
+                            rnodeinterface = RNS.Interfaces.Android.RNodeInterface.RNodeInterface(
+                                    RNS.Transport,
+                                    "RNodeInterface",
+                                    target_device["port"],
+                                    frequency = self.config["hw_rnode_frequency"],
+                                    bandwidth = self.config["hw_rnode_bandwidth"],
+                                    txpower = self.config["hw_rnode_tx_power"],
+                                    sf = self.config["hw_rnode_spreading_factor"],
+                                    cr = self.config["hw_rnode_coding_rate"],
+                                    flow_control = None,
+                                    id_interval = self.config["hw_rnode_beaconinterval"],
+                                    id_callsign = self.config["hw_rnode_beacondata"],
+                                )
+
+                            rnodeinterface.OUT = True
+                            self.reticulum._add_interface(rnodeinterface,ifac_netname=ifac_netname,ifac_netkey=ifac_netkey)
+                            self.interface_rnode = rnodeinterface
+
+                    except Exception as e:
+                        RNS.log("Error while adding RNode Interface. The contained exception was: "+str(e))
+                        self.interface_rnode = None
+
         RNS.log("Reticulum started, activating LXMF...")
+        self.setstate("init.loadingstate", "Activating LXMF Router")
         self.message_router = LXMF.LXMRouter(identity = self.identity, storagepath = self.lxmf_storage, autopeer = True)
         self.message_router.register_delivery_callback(self.lxmf_delivery)
 
